---
render-subpages: false
...

# The Meson-ui Build GUI

## Overview

Meson-ui is a Graphical application designed to provide an interactive
way to use the Meson build system. We believe it is a nice way to get
CMake users comfortable with Meson.

The main design point of Meson-ui, is that developers should have a nice
build GUI that can be summed with one simple command and count on that
GUI to provide all or most of Meson build systems features.

## Features

*   Multiplatform support for Linux, macOS, Windows, and others
*   straight forward and easy to uses graphical user interface.
*   Written documentation for Meson-ui.
*   Meson support back to version 0.50.0.
*   Optimized for extremely fast usage without sacrificing correctness.
*   Distributed under the Apache 2.0 license.
*   Works 99.95% out of the box.
*   fun!

## Development

All development on Meson-ui is done on the [GitHub
project](https://github.com/michaelbadcrumble/meson-ui). Instructions for
contributing can be found on the [contribution page](Contributing.md).


You do not need to sign a CLA to contribute to Meson.
